"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const extra_typings_1 = require("@commander-js/extra-typings");
const pkginfo_1 = __importDefault(require("pkginfo"));
const update_notifier_1 = __importDefault(require("update-notifier"));
const cmd_remove_1 = require("./cmd-remove");
const cmd_deps_1 = require("./cmd-deps");
const cmd_login_1 = require("./cmd-login");
const cli_parsing_1 = require("./cli-parsing");
const cmd_add_1 = require("./cmd-add");
const npmrc_auth_1 = require("../services/npmrc-auth");
const npm_login_1 = require("../services/npm-login");
const npm_search_1 = require("../io/npm-search");
const package_json_1 = __importDefault(require("../../package.json"));
const cmd_search_1 = require("./cmd-search");
const cmd_view_1 = require("./cmd-view");
const dependency_resolving_1 = require("../services/dependency-resolving");
const all_packuments_io_1 = require("../io/all-packuments-io");
const validators_1 = require("./validators");
const another_npm_registry_client_1 = __importDefault(require("another-npm-registry-client"));
const parse_env_1 = require("../services/parse-env");
const resolve_remote_packument_version_1 = require("../services/resolve-remote-packument-version");
const project_manifest_io_1 = require("../io/project-manifest-io");
const npmlog_1 = __importDefault(require("npmlog"));
const resolve_latest_version_1 = require("../services/resolve-latest-version");
const upm_config_io_1 = require("../io/upm-config-io");
const file_io_1 = require("../io/file-io");
const npmrc_io_1 = require("../io/npmrc-io");
const special_paths_1 = require("../io/special-paths");
const project_version_io_1 = require("../io/project-version-io");
const upm_auth_1 = require("../services/upm-auth");
const packument_io_1 = require("../io/packument-io");
const search_packages_1 = require("../services/search-packages");
const resolve_remote_packument_1 = require("../services/resolve-remote-packument");
const login_1 = require("../services/login");
// Composition root
const log = npmlog_1.default;
const regClient = new another_npm_registry_client_1.default({ log });
const getCwd = (0, special_paths_1.makeCwdGetter)();
const getHomePath = (0, special_paths_1.makeHomePathGetter)();
const readFile = (0, file_io_1.makeTextReader)();
const writeFile = (0, file_io_1.makeTextWriter)();
const loadProjectManifest = (0, project_manifest_io_1.makeProjectManifestLoader)(readFile);
const writeProjectManifest = (0, project_manifest_io_1.makeProjectManifestWriter)(writeFile);
const getUpmConfigPath = (0, upm_config_io_1.makeUpmConfigPathGetter)(getHomePath);
const loadUpmConfig = (0, upm_config_io_1.makeUpmConfigLoader)(readFile);
const findNpmrcPath = (0, npmrc_io_1.makeNpmrcPathFinder)(getHomePath);
const loadNpmrc = (0, npmrc_io_1.makeNpmrcLoader)(readFile);
const saveNpmrc = (0, npmrc_io_1.makeNpmrcSaver)(writeFile);
const loadProjectVersion = (0, project_version_io_1.makeProjectVersionLoader)(readFile);
const fetchPackument = (0, packument_io_1.makePackumentFetcher)(regClient);
const fetchAllPackuments = (0, all_packuments_io_1.makeAllPackumentsFetcher)();
const searchRegistry = (0, npm_search_1.makeRegistrySearcher)();
const resolveRemotePackument = (0, resolve_remote_packument_1.makeRemotePackumentResolver)(fetchPackument);
const parseEnv = (0, parse_env_1.makeParseEnvService)(log, getUpmConfigPath, loadUpmConfig, getCwd, loadProjectVersion);
const authNpmrc = (0, npmrc_auth_1.makeAuthNpmrcService)(findNpmrcPath, loadNpmrc, saveNpmrc);
const npmLogin = (0, npm_login_1.makeNpmLoginService)(regClient);
const resolveRemovePackumentVersion = (0, resolve_remote_packument_version_1.makeResolveRemotePackumentVersionService)(fetchPackument);
const resolveLatestVersion = (0, resolve_latest_version_1.makeResolveLatestVersionService)(fetchPackument);
const resolveDependencies = (0, dependency_resolving_1.makeResolveDependenciesService)(resolveRemovePackumentVersion, resolveLatestVersion);
const saveAuthToUpmConfig = (0, upm_auth_1.makeSaveAuthToUpmConfigService)(loadUpmConfig, writeFile);
const searchPackages = (0, search_packages_1.makePackagesSearcher)(searchRegistry, fetchAllPackuments);
const login = (0, login_1.makeLoginService)(saveAuthToUpmConfig, npmLogin, authNpmrc);
const addCmd = (0, cmd_add_1.makeAddCmd)(parseEnv, resolveRemovePackumentVersion, resolveDependencies, loadProjectManifest, writeProjectManifest, log);
const loginCmd = (0, cmd_login_1.makeLoginCmd)(parseEnv, getUpmConfigPath, login, log);
const searchCmd = (0, cmd_search_1.makeSearchCmd)(parseEnv, searchPackages, log);
const depsCmd = (0, cmd_deps_1.makeDepsCmd)(parseEnv, resolveDependencies, log);
const removeCmd = (0, cmd_remove_1.makeRemoveCmd)(parseEnv, loadProjectManifest, writeProjectManifest, log);
const viewCmd = (0, cmd_view_1.makeViewCmd)(parseEnv, resolveRemotePackument, log);
// update-notifier
(0, pkginfo_1.default)(module);
const notifier = (0, update_notifier_1.default)({ pkg: package_json_1.default });
notifier.notify();
const program = (0, extra_typings_1.createCommand)()
    .version(module.exports.version)
    .option("-c, --chdir <path>", "change the working directory")
    .option("-r, --registry <url>", "specify registry url", validators_1.mustBeRegistryUrl)
    .option("-v, --verbose", "output extra debugging")
    .option("--cn", "use the China region registry")
    .option("--system-user", "auth for Windows system user")
    .option("--wsl", "auth for Windows when using WSL")
    .option("--no-upstream", "don't use upstream unity registry")
    .option("--no-color", "disable color");
/**
 * Creates a CmdOptions object by adding global options to the given
 * specific options.
 * @param specificOptions The specific options.
 */
function makeCmdOptions(specificOptions) {
    return { ...specificOptions, _global: program.opts() };
}
program
    .command("add")
    .argument("<pkg>", "Reference to the package that should be added", validators_1.mustBePackageReference)
    .argument("[otherPkgs...]", "References to additional packages that should be added", (0, cli_parsing_1.eachValue)(validators_1.mustBePackageReference))
    .aliases(["install", "i"])
    .option("-t, --test", "add package as testable")
    .option("-f, --force", "force add package if missing deps or editor version is not qualified")
    .description(`add package to manifest json
openupm add <pkg> [otherPkgs...]
openupm add <pkg>@<version> [otherPkgs...]`)
    .action(async function (pkg, otherPkgs, options) {
    const pkgs = [pkg].concat(otherPkgs);
    const addResult = await addCmd(pkgs, makeCmdOptions(options));
    if (addResult.isErr())
        process.exit(1);
});
program
    .command("remove")
    .argument("<pkg>", "Name of the package to remove", validators_1.mustBeDomainName)
    .argument("[otherPkgs...]", "Names of additional packages to remove", (0, cli_parsing_1.eachValue)(validators_1.mustBeDomainName))
    .aliases(["rm", "uninstall"])
    .description("remove package from manifest json")
    .action(async function (pkg, otherPkgs, options) {
    const pkgs = [pkg].concat(otherPkgs);
    const removeResult = await removeCmd(pkgs, makeCmdOptions(options));
    if (removeResult.isErr())
        process.exit(1);
});
program
    .command("search")
    .argument("<keyword>", "The keyword to search")
    .aliases(["s", "se", "find"])
    .description("Search package by keyword")
    .action(async function (keyword, options) {
    const searchResult = await searchCmd(keyword, makeCmdOptions(options));
    if (searchResult.isErr())
        process.exit(1);
});
program
    .command("view")
    .argument("<pkg>", "Reference to a package", validators_1.mustBePackageReference)
    .aliases(["v", "info", "show"])
    .description("view package information")
    .action(async function (pkg, options) {
    const result = await viewCmd(pkg, makeCmdOptions(options));
    if (result.isErr())
        process.exit(1);
});
program
    .command("deps")
    .argument("<pkg>", "Reference to a package", validators_1.mustBePackageReference)
    .alias("dep")
    .option("-d, --deep", "view package dependencies recursively")
    .description(`view package dependencies
openupm deps <pkg>
openupm deps <pkg>@<version>`)
    .action(async function (pkg, options) {
    const depsResult = await depsCmd(pkg, makeCmdOptions(options));
    if (depsResult.isErr())
        process.exit(1);
});
program
    .command("login")
    .aliases(["add-user", "adduser"])
    .option("-u, --username <username>", "username")
    .option("-p, --password <password>", "password")
    .option("-e, --email <email>", "email address")
    .option("--basic-auth", "use basic authentication instead of token")
    .option("--always-auth", "always auth for tarball hosted on a different domain")
    .description("authenticate with a scoped registry")
    .action(async function (options) {
    const loginResult = await loginCmd(makeCmdOptions(options));
    if (loginResult.isErr())
        process.exit(1);
});
// prompt for invalid command
program.on("command:*", function () {
    log.warn("", `unknown command: ${program.args.join(" ")}`);
    log.warn("", "see --help for a list of available commands");
    process.exit(1);
});
program.parse(process.argv);
// print help if no command is given
if (!program.args.length)
    program.help();
//# sourceMappingURL=index.js.map