"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.formatAsTable = void 0;
const cli_table_1 = __importDefault(require("cli-table"));
const packument_1 = require("../domain/packument");
const assert_1 = __importDefault(require("assert"));
/**
 * Formats an array of packuments as a table. The table is returned
 * as a single string (Includes line breaks).
 * @param packuments The packuments.
 */
function formatAsTable(packuments) {
    const table = new cli_table_1.default({
        head: ["Name", "Version", "Date"],
        colWidths: [42, 20, 12],
    });
    function getTableRow(packument) {
        const name = packument.name;
        const version = (0, packument_1.tryGetLatestVersion)(packument);
        let date = "";
        if (packument.time && packument.time.modified)
            date = packument.time.modified.split("T")[0];
        if (packument.date) {
            date = packument.date.toISOString().slice(0, 10);
        }
        (0, assert_1.default)(version !== undefined);
        return [name, version, date];
    }
    const rows = packuments.map(getTableRow);
    rows.forEach((row) => table.push(row));
    return table.toString();
}
exports.formatAsTable = formatAsTable;
//# sourceMappingURL=output-formatting.js.map