"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.EditorVersionNotSupportedError = exports.FileParseError = exports.PackageWithVersionError = exports.PackumentNotFoundError = void 0;
const ts_custom_error_1 = require("ts-custom-error");
/**
 * Error for when the packument was not found.
 */
class PackumentNotFoundError extends ts_custom_error_1.CustomError {
    constructor() {
        super("A packument was not found.");
    }
}
exports.PackumentNotFoundError = PackumentNotFoundError;
/**
 * Error for when a function expected a package-reference with only a name
 * e.g. "com.my-package", but it also included a version e.g.
 * "com.my-package@1.2.3".
 */
class PackageWithVersionError extends ts_custom_error_1.CustomError {
    constructor() {
        super("A package-reference including a version was specified when only a name was expected.");
    }
}
exports.PackageWithVersionError = PackageWithVersionError;
/**
 * Error for when a file could not be parsed into a specific target type.
 */
class FileParseError extends ts_custom_error_1.CustomError {
    path;
    targetDescription;
    cause;
    constructor(
    /**
     * The path to the file that could not be parsed.
     */
    path, 
    /**
     * A description or name of the thing that the file was supposed to be
     * parsed to.
     */
    targetDescription, 
    /**
     * The error that caused this one.
     */
    cause) {
        super("A file could not be parsed into a specific target type.");
        this.path = path;
        this.targetDescription = targetDescription;
        this.cause = cause;
    }
}
exports.FileParseError = FileParseError;
/**
 * Error for when OpenUPM was used with an editor-version that is not supported.
 */
class EditorVersionNotSupportedError extends ts_custom_error_1.CustomError {
    version;
    _class = "EditorVersionNotSupportedError";
    constructor(
    /**
     * The unsupported version.
     */
    version) {
        super();
        this.version = version;
    }
}
exports.EditorVersionNotSupportedError = EditorVersionNotSupportedError;
//# sourceMappingURL=common-errors.js.map