"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.makePackageId = exports.isPackageId = void 0;
const domain_name_1 = require("./domain-name");
const semantic_version_1 = require("./semantic-version");
const string_utils_1 = require("../utils/string-utils");
/**
 * Checks if a string is a package-id.
 * @param s The string.
 */
function isPackageId(s) {
    const [name, version] = (0, string_utils_1.trySplitAtFirstOccurrenceOf)(s, "@");
    return (0, domain_name_1.isDomainName)(name) && version !== null && (0, semantic_version_1.isSemanticVersion)(version);
}
exports.isPackageId = isPackageId;
/**
 * Constructs a package-id.
 * @param name The package name.
 * @param version The version.
 */
function makePackageId(name, version) {
    return `${name}@${version}`;
}
exports.makePackageId = makePackageId;
//# sourceMappingURL=package-id.js.map