"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.tryGetTargetEditorVersionFor = exports.InvalidTargetEditorError = exports.dependenciesOf = void 0;
const record_utils_1 = require("../utils/record-utils");
const ts_results_es_1 = require("ts-results-es");
const editor_version_1 = require("./editor-version");
const ts_custom_error_1 = require("ts-custom-error");
/**
 * Gets a list of all dependencies for a package.
 * @param packageManifest The package.
 * @returns A list of dependencies. The dependencies are in tuple form.
 */
function dependenciesOf(packageManifest) {
    return (0, record_utils_1.recordEntries)(packageManifest["dependencies"] || {});
}
exports.dependenciesOf = dependenciesOf;
/**
 * Error for when a packument contained an invalid target editor-version.
 */
class InvalidTargetEditorError extends ts_custom_error_1.CustomError {
    versionString;
    // noinspection JSUnusedLocalSymbols
    _class = "InvalidTargetEditorError";
    constructor(
    /**
     * The invalid editor-version string.
     */
    versionString) {
        super();
        this.versionString = versionString;
    }
}
exports.InvalidTargetEditorError = InvalidTargetEditorError;
/**
 * Extracts the target editor-version from a package-manifest.
 * @param packageManifest The manifest for which to get the editor.
 * @returns The editor-version or null if the package is compatible
 * with all Unity version.
 */
function tryGetTargetEditorVersionFor(packageManifest) {
    if (packageManifest.unity === undefined)
        return (0, ts_results_es_1.Ok)(null);
    const majorMinor = packageManifest.unity;
    const release = packageManifest.unityRelease !== undefined
        ? `.${packageManifest.unityRelease}`
        : "";
    const versionString = `${majorMinor}${release}`;
    const parsed = (0, editor_version_1.tryParseEditorVersion)(versionString);
    return parsed !== null
        ? (0, ts_results_es_1.Ok)(parsed)
        : (0, ts_results_es_1.Err)(new InvalidTargetEditorError(versionString));
}
exports.tryGetTargetEditorVersionFor = tryGetTargetEditorVersionFor;
//# sourceMappingURL=package-manifest.js.map