"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.unityRegistryUrl = exports.coerceRegistryUrl = exports.makeRegistryUrl = exports.isRegistryUrl = void 0;
const assert_1 = __importDefault(require("assert"));
const string_utils_1 = require("../utils/string-utils");
/**
 * Checks that a string is a valid registry.
 * @param s The string.
 */
function isRegistryUrl(s) {
    return /http(s?):\/\/.*[^/]$/.test(s);
}
exports.isRegistryUrl = isRegistryUrl;
/**
 * Constructs a registry-url.
 * @param s The string.
 * @throws {assert.AssertionError} If string does not have valid format.
 */
function makeRegistryUrl(s) {
    (0, assert_1.default)(isRegistryUrl(s), `"${s}" is url`);
    return s;
}
exports.makeRegistryUrl = makeRegistryUrl;
/**
 * Attempts to coerce a string into a registry-url, by
 * - Prepending http if it is missing.
 * - Removing trailing slashes.
 * @param s The string.
 * @throws {assert.AssertionError} If string does not have valid format.
 */
function coerceRegistryUrl(s) {
    if (!s.toLowerCase().startsWith("http"))
        s = "http://" + s;
    s = (0, string_utils_1.removeTrailingSlash)(s);
    return makeRegistryUrl(s);
}
exports.coerceRegistryUrl = coerceRegistryUrl;
exports.unityRegistryUrl = makeRegistryUrl("https://packages.unity.com");
//# sourceMappingURL=registry-url.js.map