"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.makeEmptyScopedRegistryFor = exports.removeScope = exports.addScope = exports.hasScope = exports.makeScopedRegistry = void 0;
/**
 * Constructs a scoped registry.
 * @param name The name.
 * @param url The url.
 * @param scopes The scopes. If not specified defaults to empty array.
 */
function makeScopedRegistry(name, url, scopes) {
    return { name, url, scopes: scopes ?? [] };
}
exports.makeScopedRegistry = makeScopedRegistry;
/**
 * Checks if a registry has a specific scope.
 * @param registry The registry.
 * @param scope The scope.
 */
function hasScope(registry, scope) {
    return registry.scopes.includes(scope);
}
exports.hasScope = hasScope;
/**
 * Adds a scope to a registry if it is not already in the list. The scopes will
 * also be sorted alphabetically.
 * @param registry The registry.
 * @param scope The scope.
 */
function addScope(registry, scope) {
    if (hasScope(registry, scope))
        return registry;
    return { ...registry, scopes: [...registry.scopes, scope].sort() };
}
exports.addScope = addScope;
/**
 * Removes a scope from a registry.
 * @param registry The registry.
 * @param scope The scope.
 */
function removeScope(registry, scope) {
    return { ...registry, scopes: registry.scopes.filter((it) => it !== scope) };
}
exports.removeScope = removeScope;
/**
 * Makes an empty scoped-registry from a registry-url. The name will be
 * the registry's hostname.
 * @param registryUrl The registry-url.
 */
function makeEmptyScopedRegistryFor(registryUrl) {
    const name = new URL(registryUrl).hostname;
    return makeScopedRegistry(name, registryUrl);
}
exports.makeEmptyScopedRegistryFor = makeEmptyScopedRegistryFor;
//# sourceMappingURL=scoped-registry.js.map