"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.makeBuiltInPackagesFinder = exports.EditorNotInstalledError = void 0;
const special_paths_1 = require("./special-paths");
const ts_custom_error_1 = require("ts-custom-error");
const path_1 = __importDefault(require("path"));
const file_io_1 = require("./file-io");
/**
 * Error for when an editor-version is not installed.
 */
class EditorNotInstalledError extends ts_custom_error_1.CustomError {
    version;
    _class = "EditorNotInstalledError";
    constructor(
    /**
     * The version that is not installed.
     */
    version) {
        super();
        this.version = version;
    }
}
exports.EditorNotInstalledError = EditorNotInstalledError;
/**
 * Makes a {@link FindBuiltInPackages} function.
 */
function makeBuiltInPackagesFinder() {
    return (editorVersion) => {
        {
            const pathResult = (0, special_paths_1.tryGetEditorInstallPath)(editorVersion);
            if (pathResult.isErr())
                return pathResult.toAsyncResult();
            const installPath = pathResult.value;
            const packagesDir = path_1.default.join(installPath, "Editor/Data/Resources/PackageManager/BuiltInPackages");
            return ((0, file_io_1.tryGetDirectoriesIn)(packagesDir)
                // We can assume correct format
                .map((names) => names)
                .mapErr((error) => error.reason === file_io_1.FsErrorReason.Missing
                ? new EditorNotInstalledError(editorVersion)
                : error));
        }
    };
}
exports.makeBuiltInPackagesFinder = makeBuiltInPackagesFinder;
//# sourceMappingURL=builtin-packages.js.map