"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.makeRegistrySearcher = exports.getNpmFetchOptions = void 0;
const ts_results_es_1 = require("ts-results-es");
const libnpmsearch_1 = __importDefault(require("libnpmsearch"));
const error_type_guards_1 = require("../utils/error-type-guards");
/**
 * Get npm fetch options.
 */
const getNpmFetchOptions = function (registry) {
    const opts = {
        registry: registry.url,
    };
    const auth = registry.auth;
    if (auth !== null)
        Object.assign(opts, auth);
    return opts;
};
exports.getNpmFetchOptions = getNpmFetchOptions;
/**
 * Makes a {@link SearchRegistry} function.
 */
function makeRegistrySearcher() {
    return (registry, keyword) => {
        return new ts_results_es_1.AsyncResult((0, libnpmsearch_1.default)(keyword, (0, exports.getNpmFetchOptions)(registry))
            // NOTE: The results of the search will be packument objects, so we can change the type
            .then((results) => (0, ts_results_es_1.Ok)(results))
            .catch((error) => {
            (0, error_type_guards_1.assertIsHttpError)(error);
            return (0, ts_results_es_1.Err)(error);
        }));
    };
}
exports.makeRegistrySearcher = makeRegistrySearcher;
//# sourceMappingURL=npm-search.js.map