"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.makeProjectManifestWriter = exports.makeProjectManifestLoader = exports.manifestPathFor = void 0;
const project_manifest_1 = require("../domain/project-manifest");
const path_1 = __importDefault(require("path"));
const string_parsing_1 = require("../utils/string-parsing");
const common_errors_1 = require("../common-errors");
/**
 * Determines the path to the package manifest based on the project
 * directory.
 * @param projectPath The root path of the Unity project.
 */
function manifestPathFor(projectPath) {
    return path_1.default.join(projectPath, "Packages/manifest.json");
}
exports.manifestPathFor = manifestPathFor;
/**
 * Makes a {@link LoadProjectManifest} function.
 */
function makeProjectManifestLoader(readFile) {
    return (projectPath) => {
        const manifestPath = manifestPathFor(projectPath);
        return (readFile(manifestPath)
            .andThen(string_parsing_1.tryParseJson)
            // TODO: Actually validate the json structure
            .map((json) => json)
            .mapErr((error) => error instanceof string_parsing_1.StringFormatError
            ? new common_errors_1.FileParseError(manifestPath, "Project-manifest", error)
            : error));
    };
}
exports.makeProjectManifestLoader = makeProjectManifestLoader;
/**
 * Makes a {@link WriteProjectManifest} function.
 */
function makeProjectManifestWriter(writeFile) {
    return (projectPath, manifest) => {
        const manifestPath = manifestPathFor(projectPath);
        manifest = (0, project_manifest_1.pruneManifest)(manifest);
        const json = JSON.stringify(manifest, null, 2);
        return writeFile(manifestPath, json);
    };
}
exports.makeProjectManifestWriter = makeProjectManifestWriter;
//# sourceMappingURL=project-manifest-io.js.map