"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.pickMostFixable = exports.tryResolveFromCache = void 0;
const packument_1 = require("./domain/packument");
const packument_cache_1 = require("./packument-cache");
const ts_results_es_1 = require("ts-results-es");
const common_errors_1 = require("./common-errors");
/**
 * Attempts to resolve a packument-version from the cache.
 * @param cache The cache to search.
 * @param source The source from which to resolve.
 * @param packumentName The name of the packument to resolve.
 * @param requestedVersion The requested version.
 */
function tryResolveFromCache(cache, source, packumentName, requestedVersion) {
    const cachedPackument = (0, packument_cache_1.tryGetFromCache)(cache, source, packumentName);
    if (cachedPackument === null)
        return (0, ts_results_es_1.Err)(new common_errors_1.PackumentNotFoundError());
    return (0, packument_1.tryResolvePackumentVersion)(cachedPackument, requestedVersion).map((packumentVersion) => ({
        packument: cachedPackument,
        packumentVersion,
        source,
    }));
}
exports.tryResolveFromCache = tryResolveFromCache;
/**
 * Compares two resolve-failures to check which is more fixable.
 * @param a The first failure.
 * @param b The second failure.
 * @returns The more fixable failure.
 */
function pickMostFixable(a, b) {
    // Anything is more fixable than packument-not-found
    if (a.error instanceof common_errors_1.PackumentNotFoundError &&
        !(b.error instanceof common_errors_1.PackumentNotFoundError))
        return b;
    else if (b.error instanceof common_errors_1.PackumentNotFoundError &&
        !(a.error instanceof common_errors_1.PackumentNotFoundError))
        return a;
    return a;
}
exports.pickMostFixable = pickMostFixable;
//# sourceMappingURL=packument-version-resolving.js.map