"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.makeLoginService = void 0;
const upm_config_1 = require("../domain/upm-config");
/**
 * Makes a {@link LoginService} function.
 */
function makeLoginService(saveAuthToUpmConfig, npmLogin, authNpmrc) {
    return (username, password, email, alwaysAuth, registry, configPath, authMode, onNpmAuthSuccess, onNpmrcUpdated) => {
        if (authMode === "basic") {
            // basic auth
            const _auth = (0, upm_config_1.encodeBasicAuth)(username, password);
            return saveAuthToUpmConfig(configPath, registry, {
                email,
                alwaysAuth,
                _auth,
            });
        }
        // npm login
        return npmLogin(registry, username, password, email).andThen((token) => {
            onNpmAuthSuccess();
            // write npm token
            return authNpmrc(registry, token).andThen((npmrcPath) => {
                onNpmrcUpdated(npmrcPath);
                // Save config
                return saveAuthToUpmConfig(configPath, registry, {
                    email,
                    alwaysAuth,
                    token,
                });
            });
        });
    };
}
exports.makeLoginService = makeLoginService;
//# sourceMappingURL=login.js.map