"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.makeNpmLoginService = exports.AuthenticationError = void 0;
const ts_custom_error_1 = require("ts-custom-error");
const ts_results_es_1 = require("ts-results-es");
/**
 * Error for when authentication failed.
 */
class AuthenticationError extends ts_custom_error_1.CustomError {
    status;
    _class = "AuthenticationError";
    constructor(
    /**
     * The http-response code returned by the server.
     */
    status, message) {
        super(message);
        this.status = status;
    }
}
exports.AuthenticationError = AuthenticationError;
/**
 * Makes a new {@link NpmLoginService} function.
 */
function makeNpmLoginService(registryClient) {
    return (registryUrl, username, email, password) => {
        return new ts_results_es_1.AsyncResult(new Promise((resolve) => {
            registryClient.adduser(registryUrl, { auth: { username, email, password } }, (error, responseData, _, response) => {
                if (response !== undefined && !responseData.ok)
                    resolve((0, ts_results_es_1.Err)(new AuthenticationError(response.statusCode, response.statusMessage)));
                else if (responseData.ok)
                    resolve((0, ts_results_es_1.Ok)(responseData.token));
                // TODO: Handle error
            });
        }));
    };
}
exports.makeNpmLoginService = makeNpmLoginService;
//# sourceMappingURL=npm-login.js.map