"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.makeResolveLatestVersionService = void 0;
const ts_results_es_1 = require("ts-results-es");
const common_errors_1 = require("../common-errors");
const packument_1 = require("../domain/packument");
const record_utils_1 = require("../utils/record-utils");
function makeResolveLatestVersionService(fetchPackument) {
    const resolveLatestVersion = (sources, packageName) => {
        if (sources.length === 0)
            return (0, ts_results_es_1.Err)(new common_errors_1.PackumentNotFoundError()).toAsyncResult();
        const sourceToCheck = sources[0];
        return fetchPackument(sourceToCheck, packageName).andThen((maybePackument) => {
            if (maybePackument === null)
                return resolveLatestVersion(sources.slice(1), packageName);
            const latestVersion = (0, packument_1.tryGetLatestVersion)(maybePackument);
            if (latestVersion !== undefined)
                return (0, ts_results_es_1.Ok)(latestVersion);
            const availableVersions = (0, record_utils_1.recordKeys)(maybePackument.versions);
            if (availableVersions.length === 0)
                return (0, ts_results_es_1.Err)(new packument_1.NoVersionsError()).toAsyncResult();
            return (0, ts_results_es_1.Ok)(availableVersions.at(-1));
        });
    };
    return resolveLatestVersion;
}
exports.makeResolveLatestVersionService = makeResolveLatestVersionService;
//# sourceMappingURL=resolve-latest-version.js.map