"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.makeResolveRemotePackumentVersionService = void 0;
const ts_results_es_1 = require("ts-results-es");
const common_errors_1 = require("../common-errors");
const packument_1 = require("../domain/packument");
/**
 * Makes a {@link ResolveRemotePackumentVersionService} function.
 */
function makeResolveRemotePackumentVersionService(fetchPackument) {
    return (packageName, requestedVersion, source) => fetchPackument(source, packageName)
        .andThen((maybePackument) => {
        if (maybePackument === null)
            return (0, ts_results_es_1.Err)(new common_errors_1.PackumentNotFoundError());
        return (0, ts_results_es_1.Ok)(maybePackument);
    })
        .andThen((packument) => (0, packument_1.tryResolvePackumentVersion)(packument, requestedVersion).map((packumentVersion) => ({
        packument,
        packumentVersion,
        source: source.url,
    })));
}
exports.makeResolveRemotePackumentVersionService = makeResolveRemotePackumentVersionService;
//# sourceMappingURL=resolve-remote-packument-version.js.map