"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.makeRemotePackumentResolver = void 0;
const ts_results_es_1 = require("ts-results-es");
const noPackumentResult = (0, ts_results_es_1.Ok)(null).toAsyncResult();
function withSource(source, packument) {
    return {
        packument,
        source: source.url,
    };
}
/**
 * Makes a {@link ResolveRemotePackument} function.
 */
function makeRemotePackumentResolver(fetchPackument) {
    function tryResolveFrom(source, packageName) {
        return fetchPackument(source, packageName).map((packument) => packument !== null ? withSource(source, packument) : null);
    }
    const resolveRecursively = (packageName, sources) => {
        // If there are no more sources to search then can return with no packument
        if (sources.length === 0)
            return noPackumentResult;
        // Determine current and fallback sources
        const currentSource = sources[0];
        const fallbackSources = sources.slice(1);
        // Resolve from the current source first
        return tryResolveFrom(currentSource, packageName).andThen((maybePackument) => 
        // Afterward check if we got a packument.
        // If yes we can return it, otherwhise we enter the next level
        // of the recursion with the remaining registries.
        maybePackument !== null
            ? (0, ts_results_es_1.Ok)(maybePackument).toAsyncResult()
            : resolveRecursively(packageName, fallbackSources));
    };
    return resolveRecursively;
}
exports.makeRemotePackumentResolver = makeRemotePackumentResolver;
//# sourceMappingURL=resolve-remote-packument.js.map