"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.tryParseYaml = exports.tryParseToml = exports.tryParseJson = exports.StringFormatError = void 0;
const toml_1 = __importDefault(require("@iarna/toml"));
const ts_results_es_1 = require("ts-results-es");
const ts_custom_error_1 = require("ts-custom-error");
const yaml_1 = __importDefault(require("yaml"));
const error_type_guards_1 = require("./error-type-guards");
/**
 * Error for when a string could not be parsed to a specific format.
 */
class StringFormatError extends ts_custom_error_1.CustomError {
    formatName;
    cause;
    // noinspection JSUnusedLocalSymbols
    _class = "StringFormatError";
    constructor(
    /**
     * Description of the format the string was supposed to be parsed to.
     */
    formatName, 
    /**
     * The error which caused the parsing failure.
     */
    cause) {
        super();
        this.formatName = formatName;
        this.cause = cause;
    }
}
exports.StringFormatError = StringFormatError;
function makeParser(formatName, parsingFunction) {
    return (input) => ts_results_es_1.Result.wrap(() => parsingFunction(input)).mapErr((error) => {
        (0, error_type_guards_1.assertIsError)(error);
        return new StringFormatError(formatName, error);
    });
}
/**
 * Attempts to parse a json-string.
 * @param json The string to be parsed.
 */
exports.tryParseJson = makeParser("Json", JSON.parse);
/**
 * Attempts to parse a toml-string.
 * @param toml The string to be parsed.
 */
exports.tryParseToml = makeParser("Toml", toml_1.default.parse);
/**
 * Attempts to parse a yaml-string.
 * @param input The string to be parsed.
 */
exports.tryParseYaml = makeParser("Yaml", yaml_1.default.parse);
//# sourceMappingURL=string-parsing.js.map